{% load django_bootstrap5 %}
{% load i18n %}

<form autocomplete="off" action="{% url 'beltradar:create_session' %}" method="post">
    {% csrf_token %}

    <fieldset class="aa-beltradar-batch-ore-import-form">
        {% bootstrap_form forms.create_session %}

        <div class="form-group text-end">
            {% translate "Submit" as button_text %}
            {% bootstrap_button button_type="submit" content=button_text %}
        </div>
    </fieldset>
</form>
