{% load i18n %}
{% load navactive %}

<li class="nav-item">
    <a class="nav-link py-0" href="{% url 'beltradar:create_session' %}">
        <span class="btn btn-success">{% translate 'Add Session' %}</span>
    </a>
</li>

{% if request.user.is_superuser %}
    <li class="nav-item">
        {#<a class="nav-link py-0" href="{% url 'beltradar:admin' %}">#}
            <span class="btn btn-danger">{% translate 'Admin' %}</span>
        </a>
    </li>
{% endif %}
